@@ -8,12 +8,16 @@
  */
 
 
+#define TRUE			1
+#define FALSE			0
+
 #define QUIT			-1
 #define NEWGAME			-2
 #define RESTART			-3
 #define SAVE			-4
 #define OPEN			-5
 #define UNDO			-6
+#define NOOP			-7
 
 #define NEW			0
 #define LAST			1
