@@ -33,12 +33,15 @@
 #define CARDIMAGEWIDTH 56
 #define CARDIMAGEHEIGHT 80
 
-#define VERSION "KLONDIKE\n  v1.1"
+#define VERSION "KLONDIKE\n  v1.2"
 #define VERSIONLEFT (KL_SCREENWIDTH - 72)
 
 #ifndef CARDSFILE
 #define CARDSFILE "Cards56x80"
 #endif
+#ifndef CARDSMOUSESAMPLERATE
+#define CARDSMOUSESAMPLERATE MOUSE_DEFAULTSAMPLERATE
+#endif
 
 
 #define CARDTOIMAGE(card)	(card % NUMCARDIMAGES)
@@ -104,7 +107,9 @@ InitDisplay(int argc, char **argv)
 {
     vga_disabledriverreport();
     vga_init();
+#if !defined(CARDSMOUSE)
     vga_setmousesupport(1);
+#endif
     
     if (vga_setmode(KL_SCREENMODE) != 0) {
 	fprintf(stderr, "Mode %s not available!\n",
@@ -112,6 +117,13 @@ InitDisplay(int argc, char **argv)
 	exit(1);
     }
 
+#if defined(CARDSMOUSE)
+    mouse_init("/dev/mouse", vga_getmousetype(), CARDSMOUSESAMPLERATE);
+    mouse_setxrange(0, KL_SCREENWIDTH - 1);
+    mouse_setyrange(0, KL_SCREENHEIGHT - 1);
+    mouse_setwrap(MOUSE_NOWRAP);
+#endif
+
     vga16_init();
 
     LoadCards(CARDSFILE);
@@ -415,10 +427,13 @@ GetMouseButton()
 	if ((key = vga_getkey()) != -1) {
 	    switch (key) {
 	      case 'n':
+	      case 'N':
 		return NEWGAME;
 	      case 'r':
+	      case 'R':
 		return RESTART;
 	      case 'q':
+	      case 'Q':
 		return QUIT;
 	      default:
 		break;
