@@ -10,9 +10,6 @@
 #include "common.h"
 
 
-#define TRUE			1
-#define FALSE			0
-
 #define FROMSTOCK		-10
 #define MOVEOFF			-11
 #define TOFOUNDATION		-12
