@@ -33,11 +33,14 @@
 #define CARDIMAGEWIDTH 56
 #define CARDIMAGEHEIGHT 80
 
-#define VERSION "OH HELL!  v1.1"
+#define VERSION "OH HELL!  v1.2"
 
 #ifndef CARDSFILE
 #define CARDSFILE "Cards56x80"
 #endif
+#ifndef CARDSMOUSESAMPLERATE
+#define CARDSMOUSESAMPLERATE MOUSE_DEFAULTSAMPLERATE
+#endif
 
 #define CARDTOIMAGE(card)	(card % NUMCARDIMAGES)
 
@@ -78,7 +81,9 @@ InitDisplay(int argc, char **argv)
 {
     vga_disabledriverreport();
     vga_init();
+#if !defined(CARDSMOUSE)
     vga_setmousesupport(1);
+#endif
     
     if (vga_setmode(OH_SCREENMODE) != 0) {
 	fprintf(stderr, "Mode %s not available!\n",
@@ -86,6 +91,13 @@ InitDisplay(int argc, char **argv)
 	exit(1);
     }
 
+#if defined(CARDSMOUSE)
+    mouse_init("/dev/mouse", vga_getmousetype(), CARDSMOUSESAMPLERATE);
+    mouse_setxrange(0, OH_SCREENWIDTH - 1);
+    mouse_setyrange(0, OH_SCREENHEIGHT - 1);
+    mouse_setwrap(MOUSE_NOWRAP);
+#endif
+
     vga16_init();
 
     LoadCards(CARDSFILE);
@@ -537,8 +549,10 @@ GetMouseButton()
 	if ((key = vga_getkey()) != -1) {
 	    switch (key) {
 	      case 'n':
+	      case 'N':
 		return NEWGAME;
 	      case 'q':
+	      case 'Q':
 		return QUIT;
 	      default:
 		break;
