@@ -33,13 +33,15 @@
 #define CARDIMAGEWIDTH 56
 #define CARDIMAGEHEIGHT 80
 
-#define VERSION "SOLITAIRE\n  v1.1"
+#define VERSION "SOLITAIRE\n  v1.2"
 #define VERSIONLEFT (SO_SCREENWIDTH - 76)
 
 #ifndef CARDSFILE
 #define CARDSFILE "Cards56x80"
 #endif
-
+#ifndef CARDSMOUSESAMPLERATE
+#define CARDSMOUSESAMPLERATE MOUSE_DEFAULTSAMPLERATE
+#endif
 
 #define CARDTOIMAGE(card)	(card % NUMCARDIMAGES)
 
@@ -101,7 +103,9 @@ InitDisplay(int argc, char **argv)
 {
     vga_disabledriverreport();
     vga_init();
+#if !defined(CARDSMOUSE)
     vga_setmousesupport(1);
+#endif
     
     if (vga_setmode(SO_SCREENMODE) != 0) {
 	fprintf(stderr, "Mode %s not available!\n",
@@ -109,6 +113,13 @@ InitDisplay(int argc, char **argv)
 	exit(1);
     }
 
+#if defined(CARDSMOUSE)
+    mouse_init("/dev/mouse", vga_getmousetype(), CARDSMOUSESAMPLERATE);
+    mouse_setxrange(0, SO_SCREENWIDTH - 1);
+    mouse_setyrange(0, SO_SCREENHEIGHT - 1);
+    mouse_setwrap(MOUSE_NOWRAP);
+#endif
+
     vga16_init();
 
     LoadCards(CARDSFILE);
@@ -354,12 +365,16 @@ GetMouseButton()
 	if ((key = vga_getkey()) != -1) {
 	    switch (key) {
 	      case 'n':
+	      case 'N':
 		return NEWGAME;
 	      case 'r':
+	      case 'R':
 		return RESTART;
 	      case 'u':
+	      case 'U':
 		return UNDO;
 	      case 'q':
+	      case 'Q':
 		return QUIT;
 	      default:
 		break;
