@@ -33,11 +33,14 @@
 #define CARDIMAGEWIDTH 56
 #define CARDIMAGEHEIGHT 80
 
-#define VERSION "SPIDER\n v1.1"
+#define VERSION "SPIDER\n v1.2"
 
 #ifndef CARDSFILE
 #define CARDSFILE "Cards56x80"
 #endif
+#ifndef CARDSMOUSESAMPLERATE
+#define CARDSMOUSESAMPLERATE MOUSE_DEFAULTSAMPLERATE
+#endif
 
 
 #define CARDTOIMAGE(card)	(card % NUMCARDIMAGES)
@@ -106,7 +109,9 @@ InitDisplay(int argc, char **argv)
 {
     vga_disabledriverreport();
     vga_init();
+#if !defined(CARDSMOUSE)
     vga_setmousesupport(1);
+#endif
     
     if (vga_setmode(SP_SCREENMODE) != 0) {
 	fprintf(stderr, "Mode %s not available!\n",
@@ -114,6 +119,13 @@ InitDisplay(int argc, char **argv)
 	exit(1);
     }
 
+#if defined(CARDSMOUSE)
+    mouse_init("/dev/mouse", vga_getmousetype(), CARDSMOUSESAMPLERATE);
+    mouse_setxrange(0, SP_SCREENWIDTH - 1);
+    mouse_setyrange(0, SP_SCREENHEIGHT - 1);
+    mouse_setwrap(MOUSE_NOWRAP);
+#endif
+
     vga16_init();
 
     LoadCards(CARDSFILE);
@@ -411,12 +423,16 @@ GetMouseButton()
 	if ((key = vga_getkey()) != -1) {
 	    switch (key) {
 	      case 'n':
+	      case 'N':
 		return NEWGAME;
 	      case 'r':
+	      case 'R':
 		return RESTART;
 	      case 'u':
+	      case 'U':
 		return UNDO;
 	      case 'q':
+	      case 'Q':
 		return QUIT;
 	      default:
 		break;
